<?php
	require_once(CI_PATH_LIBS.'/config.inc.php');

	class CI_CHANNELS_SIP extends CI_CONFIG
	{
		function CI_CHANNELS_SIP()
		{

		}
		
		function get_config_file()
		{
			return CORE_PATH_BASE.'/config/drivers/sip.xml';
		}

		function set_flag_reload()
		{
			ci_set_core_flag('channels_manager.reload-sip', '1');
		}

		function get_flag_reload()
		{
			return ci_get_core_flag('channels_manager.reload-sip');
		}

		function get_map($info)
		{
			return array(
				'id'				=> $info['id'],
				'desc'				=> $info['desc'],
				'ip'				=> $info['ip'],
				'port'				=> $info['port'],
				'auth_mode'			=> $info['auth-mode'],
				'link_mode'			=> $info['link-mode'],
				'username'			=> $info['username'],
				'password'			=> $info['password'],
				'authuser'			=> $info['authuser'],
				'enabled'			=> $info['enabled'],
				'max_calls'			=> $info['max-calls'],
				'dtmf_mode'			=> $info['dtmf-mode'],
				'dtmf_duration'		=> $info['dtmf-duration'],
				'packet_size'		=> $info['packet-size']
			);
		}

		function get_rmap($info)
		{
			return array(
				'id'				=> $info['id'],
				'desc'				=> $info['desc'],
				'ip'				=> $info['ip'],
				'port'				=> intval($info['port']),
				'auth-mode'			=> $info['auth_mode'],
				'link-mode'			=> $info['link_mode'],
				'username'			=> $info['username'],
				'password'			=> $info['password'],
				'authuser'			=> $info['authuser'],
				'enabled'			=> $info['enabled'],
				'max-calls'			=> intval($info['max_calls']),
				'dtmf-mode'			=> $info['dtmf_mode'],
				'dtmf-duration'		=> intval($info['dtmf_duration']),
				'packet-size'		=> intval($info['packet_size'])
			);
		}

		function get_global_map($info)
		{
			if (!$info['ip']) $info['ip']='auto';
			
			return array(
				'sip_port'								=> $info['port'],
				'sip_ip'								=> $info['ip'],
				'sip_learn_port'						=> $info['learn-port'],
				'sip_use_rport'							=> $info['use-rport'],
				'sip_dont_use_101'						=> $info['dont-use-101'],
				'sip_agent_name'						=> $info['agent-name'],
				'sip_realm'								=> $info['realm'],
				'sip_rtp_time_jump_limit'				=> $info['rtp']['time-jump-limit'],
				'sip_rtp_jitter_compensation'			=> $info['rtp']['jitter-compensation'],
				'sip_rtp_adaptive_jitter_compensation'	=> $info['rtp']['adaptive-jitter-compensation'],
				'sip_rtp_scheduling_mode'				=> $info['rtp']['scheduling-mode']
			);
		}

		function get_global_rmap($info)
		{
			if (!$info['sip_ip']) $info['sip_ip']='auto';
			
			return array(
				'ip'				=> $info['sip_ip'],
				'port'				=> $info['sip_port'],
				'learn-port'		=> $info['sip_learn_port'],
				'use-rport'			=> $info['sip_use_rport'],
				'dont-use-101'		=> $info['sip_dont_use_101'],
				'agent-name'		=> $info['sip_agent_name'],
				'realm'				=> $info['sip_realm'],
				'rtp'	=> array(
					'time-jump-limit'				=> intval($info['sip_rtp_time_jump_limit']),
					'jitter-compensation'			=> intval($info['sip_rtp_jitter_compensation']),
					'adaptive-jitter-compensation'	=> $info['sip_rtp_adaptive_jitter_compensation'],
					'scheduling-mode'				=> $info['sip_rtp_scheduling_mode']
				)
			);
		}

		function get_global_info()
		{
			$config =& ci_get_unserialized_xml($this->get_config_file());
			return $this->get_global_map($config['sip']);
		}

		function task_save_global($info)
		{
			$config 		=& ci_get_unserialized_xml($this->get_config_file());

			$payloads=$config['sip']['rtp']['payloads'];
			
			$config['sip']						=& $this->get_global_rmap($info);
			$config['sip']['rtp']['payloads']	=& $payloads;

			$this->set_flag_reload();

			ci_save_xml($this->get_config_file(), $config, 'config');
			return ci_response_ok();
		}

		function save_raw_config($array)
		{
			$config =& ci_get_unserialized_xml($this->get_config_file());
			if (!sizeof($array))
				$array2=array();
			else
				$array2['item'] =& $array;

			$config['agents']=$array2;

			$this->set_flag_reload();

			ci_save_xml($this->get_config_file(), $config);
			return ci_response_ok();
		}

		function get_raw_list()
		{
			$config =& ci_get_unserialized_xml($this->get_config_file());
			if (!$config['agents']['item']) return array();
			
			return ci_normalize_xml_array($config['agents']['item']);
		}

		function get_info($id)
		{
			$info =& parent::get_info($id);
			if (sizeof($info)) return $info;

			/* Empty (default values) */
			return array(
				'packet_size'		=> '20',
				'dtmf_mode'			=> 'rfc2833',
				'dtmf_duration'		=> '300',
				'link_mode'			=> 'user',
    			'enabled'			=> 'true'
			);
		}

		function task_save($info)
		{
			/* New item, let's create one ID */
			if (!$info['id'])			$info['id']=md5(uniqid(''));
			
			/* Filter params */
			if ($info['auth_mode'] == 'trusted')
			{
				if (!$info['ip']) return ci_response_error(
					'field',
					array(
						'fieldname' => !$info['ip'] ? 'ip' : 'port',
						'desc'		=> ci_lbl('libchannels_sip.error.missing-ip-or-port-on-trusted')
					)
				);
			}
			else
			{
				if (!$info['authuser'] || !$info['password']) return ci_response_error(
					'field',
					array(
						'fieldname' => !$info['authuser'] ? 'authuser' : 'password',
						'desc'		=> ci_lbl('libchannels_sip.error.missing-credentials-on-auth')
					)
				);
			}

			if (!$info['username']) return ci_response_error(
					'field',
					array(
						'fieldname' => 'username',
						'desc'		=> ci_lbl('libchannels_sip.error.missing-username')
					)
				);

			/* Compose fields */
			$fields=$this->get_rmap($info);
			if (!$fields['port']) $fields['port']="";

			/* Retrieve item position */
			$n=$this->get_n($info['id']);

			/* Save */
			$list =& $this->get_raw_list();
			$list[$n]=$fields;

			$this->save_raw_config($list);
			return ci_response_ok();
		}
	}
?>