#!/usr/bin/env python

# Copyright and license: Please refer to LICENSE.TXT

import sys
import os
import os.path
import string
import re
import time

_selfpath=(os.path.dirname(os.path.realpath(__file__)).split('/'))[:-1]
_selfpath.append('pylibs')
_libspath='/'.join(_selfpath)
sys.path.append(_libspath)

from castiron import *

# Variables replace
def set_vars(txt, replace):
	if not txt: txt=""

	for k in replace.keys():

		if not replace[k]: replace[k]=""
		txt=re.sub(r'\$\{'+k+'\}', replace[k], txt)

	return txt

# Check config parameters
CORE_CONF_SYSTEM	= xml_to_array(CORE_PATH_BASE+'/config/system.xml')
CORE_CONF_SKYPE		= xml_to_array(CORE_PATH_BASE+'/config/skype.xml', 0)

# Environmental data
user_name = os.environ['from_skype']

# User lookup
S2P_USER_INFO=0
for item in CORE_CONF_SKYPE['item'].values():
	if item['+']['skype'][0]['+']['username'][0]['#'] == user_name:
		S2P_USER_INFO=xml_simplify_array(item)
		break

if not S2P_USER_INFO: sys.exit(-1)

if S2P_USER_INFO['filetransfer']['enabled'] != 'true':
	os.unlink(os.environ['file_path'])
	sys.exit(0)

# Email
subject	= S2P_USER_INFO['userdata']['castiron-filetransfer-message-template-subject']
body	= S2P_USER_INFO['userdata']['castiron-filetransfer-message-template-body']

# System environ
fp=open('/etc/hostname', 'r')
hostname=re.sub(r'[\n\r]+', '', fp.read())
fp.close()

# Variables
sys_vars={
	'sysname':			CORE_CONF_SYSTEM['hq']['sysname'],
	'account':			user_name,
	'server':			hostname,
	'hostname':			hostname,
	'date-time':		time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()),
	'user-name':		os.environ['user_name'],
	'user-dispname':	os.environ['user_dispname'],
	'file-name':		os.environ['file_name'],
	'file-size':		os.environ['file_size']
}

# Replacement
subject	= set_vars(subject, sys_vars)
body	= set_vars(body, sys_vars)

s2p_log("castiron", "info", "Receiving file '"+os.environ['file_name']+"' from "+os.environ['user_name']+" to "+user_name)

res=ci_media_send({
	'media': 	S2P_USER_INFO['userdata']['castiron-filetransfer-media'],
	'subject':	subject,
	'body':		body,
	'files':	[os.environ['file_path']]
})

if not res: s2p_log("castiron", "error", "Could not send file '"+os.environ['file_name']+"' for a media error")
os.unlink(os.environ['file_path'])


