########################################################################################
# Calls management

class S2P_CHANNELS_CALL:

	def __init__(self, parent, module, callid):
		self._callid=callid
		self._parent=parent
		self._properties={}
		self._module=module
		self._tcp_capture=0
		self._tcp_playback=0

		self.update("start")

	def __repr__(self):
		return "[s2p-chan-call: %s/%s]" % (self._module, self._callid)

	def update(self, status):
		if not self._tcp_capture or not self._tcp_playback:
			res=self._command("get_call_server")
			if self._parent.is_error(res): return

			self._tcp_playback=int(res['args']['playback'])
			self._tcp_capture=int(res['args']['capture'])
			
		self._properties=self._retrieve_properties()
		self._status=status

		# SIP port remove
		if self._properties.has_key('from'):
			self._properties['from']=self._module+':'+re.sub(r':\d+$', '', self._properties['from'])
			self._properties['from2']=self._module+':'+re.sub(r':\d+$', '', self._properties['from2'])
			self._properties['from3']=self._module+':'+re.sub(r':\d+$', '', self._properties['from3'])
			self._properties['from4']=self._module+':'+re.sub(r':\d+$', '', self._properties['from4'])

	def get_tcp_capture(self):
		return self._tcp_capture

	def get_tcp_playback(self):
		return self._tcp_playback

	def get_status(self):
		return self._status
	
	def get_properties(self):
		return self._properties
	
	def get_module(self):
		return self._module

	def _retrieve_properties(self):
		res=self._command("get_call_info")
		if not self._parent.is_error(res): return res['args']

		return {}

	def _command(self, command, args={}):
		args['call-id']=self._callid
		return self._parent.command(self._module, command, args)

########################################################################################
# Public functions

	def get_id(self):
		return self._callid

	def get(self, key):
		if not self._properties.has_key(key): return ""
		return self._properties[key]

	def set(self, key, value):
		args={'key': key, 'value': value}
		self._properties[key]=value
		res=self._command("call_set_property", args)
		return (not self._parent.is_error(res), res)

	def send_invite(self, args={}):
		res=self._command("call_start", args)
		return (not self._parent.is_error(res), res)

	def send_progress(self, args={}):
		res=self._command("call_progress", args)
		return (not self._parent.is_error(res), res)

	def send_answer(self, args={}):
		res=self._command("call_answer", args)
		return (not self._parent.is_error(res), res)

	def send_ringing(self, args={}):
		res=self._command("call_ringing", args)
		return (not self._parent.is_error(res), res)

	def send_finished(self, args={}):
		res=self._command("call_finished", args)
		return (not self._parent.is_error(res), res)

	def send_failed(self, args={}):
		res=self._command("call_failed", args)
		return (not self._parent.is_error(res), res)

	def send_hold(self, args={}):
		res=self._command("call_hold", args)
		return (not self._parent.is_error(res), res)

	def send_resume(self, args={}):
		res=self._command("call_resume", args)
		return (not self._parent.is_error(res), res)

	def send_dtmf(self, args={}):
		res=self._command("call_dtmf", args)
		return (not self._parent.is_error(res), res)

	def send_mute(self, args={}):
		res=self._command("call_mute", args)
		return (not self._parent.is_error(res), res)
	